==> bobinserters_0.15.0.zip: bobinserters_0.15.0/prototypes/styles.lua <==
data.raw["gui-style"]["default"]["bob-table"] =
{
  type = "table_style",
  cell_spacing = 0,
  horizontal_spacing = 0,
  vertical_spacing = 0
}

data.raw["gui-style"]["default"]["bob-inserter-checkbox"] =
{
  type = "checkbox_style",
  font = "default",
  font_color = {r=1, g=1, b=1},
  top_padding = 0,
  right_padding = 0,
  bottom_padding = 0,
  left_padding = 0,
  width = 32,
  height = 32,
  default_background =
  {
    filename = "__bobinserters__/graphics/gui/gui-button.png",
    priority = "extra-high-no-scale",
    scale = 2,
    width = 32,
    height = 32
  },
  hovered_background =
  {
    filename = "__bobinserters__/graphics/gui/gui-button-hover.png",
    priority = "extra-high-no-scale",
    scale = 2,
    width = 32,
    height = 32
  },
  clicked_background =
  {
    filename = "__bobinserters__/graphics/gui/gui-button-pressed.png",
    priority = "extra-high-no-scale",
    scale = 2,
    width = 32,
    height = 32
  },
  checked =
  {
    filename = "__bobinserters__/graphics/gui/gui-button-check.png",
    priority = "extra-high-no-scale",
    width = 32,
    height = 32
  }
}

data.raw["gui-style"]["default"]["bob-inserter-blank"] =
{
  type = "checkbox_style",
  font = "default",
  font_color = {r=1, g=1, b=1},
  top_padding = 0,
  right_padding = 0,
  bottom_padding = 0,
  left_padding = 0,
  width = 32,
  height = 32,
  default_background =
  {
    filename = "__bobinserters__/graphics/gui/gui-button-blank.png",
    priority = "extra-high-no-scale",
    scale = 2,
    width = 32,
    height = 32
  },
  hovered_background =
  {
    filename = "__bobinserters__/graphics/gui/gui-button-blank.png",
    priority = "extra-high-no-scale",
    scale = 2,
    width = 32,
    height = 32
  },
  clicked_background =
  {
    filename = "__bobinserters__/graphics/gui/gui-button-blank.png",
    priority = "extra-high-no-scale",
    scale = 2,
    width = 32,
    height = 32
  },
  checked =
  {
    filename = "__bobinserters__/graphics/gui/gui-button-blank.png",
    priority = "extra-high-no-scale",
    width = 32,
    height = 32
  }
}

data.raw["gui-style"]["default"]["bob-inserter-middle"] =
{
  type = "checkbox_style",
  font = "default",
  font_color = {r=1, g=1, b=1},
  top_padding = 0,
  right_padding = 0,
  bottom_padding = 0,
  left_padding = 0,
  width = 32,
  height = 32,
  default_background =
  {
    filename = "__bobinserters__/graphics/gui/gui-button-middle.png",
    priority = "extra-high-no-scale",
    scale = 2,
    width = 32,
    height = 32
  },
  hovered_background =
  {
    filename = "__bobinserters__/graphics/gui/gui-button-middle.png",
    priority = "extra-high-no-scale",
    scale = 2,
    width = 32,
    height = 32
  },
  clicked_background =
  {
    filename = "__bobinserters__/graphics/gui/gui-button-middle.png",
    priority = "extra-high-no-scale",
    scale = 2,
    width = 32,
    height = 32
  },
  checked =
  {
    filename = "__bobinserters__/graphics/gui/gui-button-blank.png",
    priority = "extra-high-no-scale",
    width = 32,
    height = 32
  }
}

data.raw["gui-style"]["default"]["bob-inserter-checkbox-pickup"] =
{
  type = "checkbox_style",
  font = "default",
  font_color = {r=1, g=1, b=1},
  top_padding = 0,
  right_padding = 0,
  bottom_padding = 0,
  left_padding = 0,
  width = 32,
  height = 32,
  default_background =
  {
    filename = "__bobinserters__/graphics/gui/gui-button.png",
    priority = "extra-high-no-scale",
    scale = 2,
    width = 32,
    height = 32
  },
  hovered_background =
  {
    filename = "__bobinserters__/graphics/gui/gui-button-hover.png",
    priority = "extra-high-no-scale",
    scale = 2,
    width = 32,
    height = 32
  },
  clicked_background =
  {
    filename = "__bobinserters__/graphics/gui/gui-button-pressed.png",
    priority = "extra-high-no-scale",
    scale = 2,
    width = 32,
    height = 32
  },
  checked =
  {
    filename = "__bobinserters__/graphics/gui/gui-button-check-pickup.png",
    priority = "extra-high-no-scale",
    width = 32,
    height = 32
  }
}

data.raw["gui-style"]["default"]["bob-inserter-checkbox-drop"] =
{
  type = "checkbox_style",
  font = "default",
  font_color = {r=1, g=1, b=1},
  top_padding = 0,
  right_padding = 0,
  bottom_padding = 0,
  left_padding = 0,
  width = 32,
  height = 32,
  default_background =
  {
    filename = "__bobinserters__/graphics/gui/gui-button.png",
    priority = "extra-high-no-scale",
    scale = 2,
    width = 32,
    height = 32
  },
  hovered_background =
  {
    filename = "__bobinserters__/graphics/gui/gui-button-hover.png",
    priority = "extra-high-no-scale",
    scale = 2,
    width = 32,
    height = 32
  },
  clicked_background =
  {
    filename = "__bobinserters__/graphics/gui/gui-button-pressed.png",
    priority = "extra-high-no-scale",
    scale = 2,
    width = 32,
    height = 32
  },
  checked =
  {
    filename = "__bobinserters__/graphics/gui/gui-button-check-drop.png",
    priority = "extra-high-no-scale",
    width = 32,
    height = 32
  }
}

data.raw["gui-style"]["default"]["bob-inserter-checkbox-small"] =
{
  type = "checkbox_style",
  font = "default",
  font_color = {r=1, g=1, b=1},
  top_padding = 0,
  right_padding = 0,
  bottom_padding = 0,
  left_padding = 0,
  width = 16,
  height = 16,
  default_background =
  {
    filename = "__bobinserters__/graphics/gui/gui-button-small.png",
    priority = "extra-high-no-scale",
    width = 16,
    height = 16
  },
  hovered_background =
  {
    filename = "__bobinserters__/graphics/gui/gui-button-small-hover.png",
    priority = "extra-high-no-scale",
    width = 16,
    height = 16
  },
  clicked_background =
  {
    filename = "__bobinserters__/graphics/gui/gui-button-small-pressed.png",
    priority = "extra-high-no-scale",
    width = 16,
    height = 16
  },
  checked =
  {
    filename = "__bobinserters__/graphics/gui/gui-button-small-check.png",
    priority = "extra-high-no-scale",
    width = 16,
    height = 16
  }
}

==> bobinserters_0.16.8.zip: bobinserters_0.16.8/prototypes/styles.lua <==
data.raw["gui-style"]["default"]["bob-table"] =
{
  type = "table_style",
  cell_spacing = 0,
  horizontal_spacing = 0,
  vertical_spacing = 0
}

data.raw["gui-style"]["default"]["bob-inserter-checkbox"] =
{
  type = "checkbox_style",
  font = "default",
  font_color = {r=1, g=1, b=1},
  top_padding = 0,
  right_padding = 0,
  bottom_padding = 0,
  left_padding = 0,
  width = 32,
  height = 32,
  default_background =
  {
    filename = "__bobinserters__/graphics/gui/checkbox-big.png",
    priority = "extra-high-no-scale",
    scale = 2,
    width = 32,
    height = 32
  },
  hovered_background =
  {
    filename = "__bobinserters__/graphics/gui/checkbox-big.png",
    priority = "extra-high-no-scale",
    x = 32,
    scale = 2,
    width = 32,
    height = 32
  },
  clicked_background =
  {
    filename = "__bobinserters__/graphics/gui/checkbox-big.png",
    priority = "extra-high-no-scale",
    x = 64,
    scale = 2,
    width = 32,
    height = 32
  },
  checked =
  {
    filename = "__bobinserters__/graphics/gui/checkbox-big.png",
    priority = "extra-high-no-scale",
    x = 96,
    width = 32,
    height = 32
  }
}

data.raw["gui-style"]["default"]["bob-inserter-blank"] =
{
  type = "checkbox_style",
  font = "default",
  font_color = {r=1, g=1, b=1},
  top_padding = 0,
  right_padding = 0,
  bottom_padding = 0,
  left_padding = 0,
  width = 32,
  height = 32,
  default_background =
  {
    filename = "__bobinserters__/graphics/gui/checkbox-big.png",
    priority = "extra-high-no-scale",
    x = 96,
    y = 32,
    scale = 2,
    width = 32,
    height = 32
  },
  hovered_background =
  {
    filename = "__bobinserters__/graphics/gui/checkbox-big.png",
    priority = "extra-high-no-scale",
    x = 96,
    y = 32,
    scale = 2,
    width = 32,
    height = 32
  },
  clicked_background =
  {
    filename = "__bobinserters__/graphics/gui/checkbox-big.png",
    priority = "extra-high-no-scale",
    x = 96,
    y = 32,
    scale = 2,
    width = 32,
    height = 32
  },
  checked =
  {
    filename = "__bobinserters__/graphics/gui/checkbox-big.png",
    priority = "extra-high-no-scale",
    x = 96,
    y = 32,
    width = 32,
    height = 32
  }
}

data.raw["gui-style"]["default"]["bob-inserter-middle"] =
{
  type = "checkbox_style",
  font = "default",
  font_color = {r=1, g=1, b=1},
  top_padding = 0,
  right_padding = 0,
  bottom_padding = 0,
  left_padding = 0,
  width = 32,
  height = 32,
  default_background =
  {
    filename = "__bobinserters__/graphics/gui/checkbox-big.png",
    priority = "extra-high-no-scale",
    y = 32,
    scale = 2,
    width = 32,
    height = 32
  },
  hovered_background =
  {
    filename = "__bobinserters__/graphics/gui/checkbox-big.png",
    priority = "extra-high-no-scale",
    y = 32,
    scale = 2,
    width = 32,
    height = 32
  },
  clicked_background =
  {
    filename = "__bobinserters__/graphics/gui/checkbox-big.png",
    priority = "extra-high-no-scale",
    y = 32,
    scale = 2,
    width = 32,
    height = 32
  },
  checked =
  {
    filename = "__bobinserters__/graphics/gui/checkbox-big.png",
    priority = "extra-high-no-scale",
    x = 96,
    y = 32,
    width = 32,
    height = 32
  }
}

data.raw["gui-style"]["default"]["bob-inserter-checkbox-pickup"] =
{
  type = "checkbox_style",
  font = "default",
  font_color = {r=1, g=1, b=1},
  top_padding = 0,
  right_padding = 0,
  bottom_padding = 0,
  left_padding = 0,
  width = 32,
  height = 32,
  default_background =
  {
    filename = "__bobinserters__/graphics/gui/checkbox-big.png",
    priority = "extra-high-no-scale",
    scale = 2,
    width = 32,
    height = 32
  },
  hovered_background =
  {
    filename = "__bobinserters__/graphics/gui/checkbox-big.png",
    priority = "extra-high-no-scale",
    x = 32,
    scale = 2,
    width = 32,
    height = 32
  },
  clicked_background =
  {
    filename = "__bobinserters__/graphics/gui/checkbox-big.png",
    priority = "extra-high-no-scale",
    x = 64,
    scale = 2,
    width = 32,
    height = 32
  },
  checked =
  {
    filename = "__bobinserters__/graphics/gui/checkbox-big.png",
    priority = "extra-high-no-scale",
    x = 32,
    y = 32,
    width = 32,
    height = 32
  }
}

data.raw["gui-style"]["default"]["bob-inserter-checkbox-drop"] =
{
  type = "checkbox_style",
  font = "default",
  font_color = {r=1, g=1, b=1},
  top_padding = 0,
  right_padding = 0,
  bottom_padding = 0,
  left_padding = 0,
  width = 32,
  height = 32,
  default_background =
  {
    filename = "__bobinserters__/graphics/gui/checkbox-big.png",
    priority = "extra-high-no-scale",
    scale = 2,
    width = 32,
    height = 32
  },
  hovered_background =
  {
    filename = "__bobinserters__/graphics/gui/checkbox-big.png",
    priority = "extra-high-no-scale",
    x = 32,
    scale = 2,
    width = 32,
    height = 32
  },
  clicked_background =
  {
    filename = "__bobinserters__/graphics/gui/checkbox-big.png",
    priority = "extra-high-no-scale",
    x = 64,
    scale = 2,
    width = 32,
    height = 32
  },
  checked =
  {
    filename = "__bobinserters__/graphics/gui/checkbox-big.png",
    priority = "extra-high-no-scale",
    x = 64,
    y = 32,
    width = 32,
    height = 32
  }
}

data.raw["gui-style"]["default"]["bob-inserter-checkbox-small"] =
{
  type = "checkbox_style",
  font = "default",
  font_color = {r=1, g=1, b=1},
  top_padding = 0,
  right_padding = 0,
  bottom_padding = 0,
  left_padding = 0,
  width = 16,
  height = 16,
  default_background =
  {
    filename = "__bobinserters__/graphics/gui/checkbox.png",
    priority = "extra-high-no-scale",
    x = 0,
    width = 16,
    height = 16
  },
  hovered_background =
  {
    filename = "__bobinserters__/graphics/gui/checkbox.png",
    priority = "extra-high-no-scale",
    x = 16,
    width = 16,
    height = 16
  },
  clicked_background =
  {
    filename = "__bobinserters__/graphics/gui/checkbox.png",
    priority = "extra-high-no-scale",
    x = 32,
    width = 16,
    height = 16
  },
  checked =
  {
    filename = "__bobinserters__/graphics/gui/checkbox.png",
    priority = "extra-high-no-scale",
    x = 48,
    width = 16,
    height = 16
  }
}


data.raw["gui-style"]["default"]["bob-logistics-checkbox"] =
{
  type = "checkbox_style",
  font = "default",
  font_color = {r=1, g=1, b=1},
  default_background =
  {
    filename = "__bobinserters__/graphics/gui/checkbox.png",
    priority = "extra-high-no-scale",
    x = 0,
    width = 16,
    height = 16
  },
  hovered_background =
  {
    filename = "__bobinserters__/graphics/gui/checkbox.png",
    priority = "extra-high-no-scale",
    x = 16,
    width = 16,
    height = 16
  },
  clicked_background =
  {
    filename = "__bobinserters__/graphics/gui/checkbox.png",
    priority = "extra-high-no-scale",
    x = 32,
    width = 16,
    height = 16
  },
  checked =
  {
    filename = "__bobinserters__/graphics/gui/checkbox.png",
    priority = "extra-high-no-scale",
    x = 48,
    width = 16,
    height = 16
  }
}
